==> openGion6.4.3.2_src.zip: gf/src/org/opengion/plugin/daemon/MailDaemon.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.daemon;

import java.util.Date;

import org.opengion.fukurou.util.HybsTimerTask;
import org.opengion.fukurou.system.LogWriter;

import org.opengion.hayabusa.mail.MailManager_DB;

/**
 * メールパラメータテーブルを監視して、メール送信プログラムを呼び出します。
 * このクラスは、HybsTimerTask を継承した タイマータスククラスです。
 * startDaemon() がタイマータスクによって、呼び出されます。
 *
 * @og.group メールモジュール
 *
 * @version  4.0
 * @author   Sen.Li
 * @since    JDK1.6
 */
public class MailDaemon extends HybsTimerTask {

	private static final int LOOP_COUNTER = 24; // カウンタを24回に設定

	private int loopCnt ;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public MailDaemon() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	/**
	 * このタイマータスクによって初期化されるアクションです。
	 * パラメータを使用した初期化を行います。
	 *
	 */
	@Override
	public void initDaemon() {
		// 何もありません。(PMD エラー回避)
	}

	/**
	 * タイマータスクのデーモン処理の開始ポイントです。
	 *
	 */
	@Override
	protected void startDaemon() {
		if( loopCnt % LOOP_COUNTER == 0 ) {
			loopCnt = 1;
			System.out.println( toString() + " " + new Date()  + " " );
		}
		else {
			String systemId = null;
			try {
				systemId = getValue( "SYSTEM_ID" );
				final MailManager_DB manager = new MailManager_DB();
				manager.sendDBMail( systemId );
			}
			catch( RuntimeException rex ) {
				final String errMsg = "メール送信失敗しました。"
							+ " SYSTEM_ID=" + systemId ;			// 5.1.8.0 (2010/07/01) errMsg 修正
				LogWriter.log( errMsg );
			}
			loopCnt++ ;
		}
	}
}

==> openGion7.3.1.2_src.zip: gf/src/org/opengion/plugin/daemon/MailDaemon.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.daemon;

import java.util.Date;

import org.opengion.fukurou.util.HybsTimerTask;
import org.opengion.fukurou.system.LogWriter;

import org.opengion.hayabusa.mail.MailManager_DB;

/**
 * メールパラメータテーブルを監視して、メール送信プログラムを呼び出します。
 * このクラスは、HybsTimerTask を継承した タイマータスククラスです。
 * startDaemon() がタイマータスクによって、呼び出されます。
 *
 * @og.group メールモジュール
 *
 * @version  4.0
 * @author   Sen.Li
 * @since    JDK1.6
 */
public class MailDaemon extends HybsTimerTask {

	private static final int LOOP_COUNTER = 24; // カウンタを24回に設定

	private int loopCnt ;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public MailDaemon() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * このタイマータスクによって初期化されるアクションです。
	 * パラメータを使用した初期化を行います。
	 *
	 */
	@Override
	public void initDaemon() {
		// 何もありません。(PMD エラー回避)
	}

	/**
	 * タイマータスクのデーモン処理の開始ポイントです。
	 *
	 */
	@Override
	protected void startDaemon() {
		if( loopCnt % LOOP_COUNTER == 0 ) {
			loopCnt = 1;
			System.out.println( toString() + " " + new Date()  + " " );
		}
		else {
			String systemId = null;
			try {
				systemId = getValue( "SYSTEM_ID" );
				final MailManager_DB manager = new MailManager_DB();
				manager.sendDBMail( systemId );
			}
			catch( final RuntimeException rex ) {
				final String errMsg = "メール送信失敗しました。"
							+ " SYSTEM_ID=" + systemId 			// 5.1.8.0 (2010/07/01) errMsg 修正
							+ " " + rex.getMessage();			// 5.10.7.0 (2019/01/11) 追加
				LogWriter.log( errMsg );
			}
			loopCnt++ ;
		}
	}
}
